@@ -139,17 +139,17 @@
 ## Select all EE features that are connected to features in
 ## the HT image.
 ## @end enumerate
-## 
+##
 ## The parameters for the method is given in a vector:
 ## @table @asis
 ## @item params(1)==0 or 4 or 8
-## Perform x connected dilatation (step 3).
+## Perform x connected dilation (step 3).
 ## @item params(2)
-## Dilatation coefficient (threshold) in step 3.
+## Dilation coefficient (threshold) in step 3.
 ## @item params(3)
-## Length of edge extention convolution (step 2).
+## Length of edge extension convolution (step 2).
 ## @item params(4)
-## Coefficient of extention convolution in step 2.
+## Coefficient of extension convolution in step 2.
 ## @end table
 ## defaults = [8, 1, 3, 3]
 ##
@@ -462,25 +462,25 @@ function [imout, thresh] = edge_andy (im, thresh, param2)
       end
       # dilation threshold
       if length(param2) > 2; tt= param2(2); end
-      # edge extention length
+      # edge extension length
       if length(param2) > 2; sz= param2(3); end
-      # edge extention threshold
+      # edge extension threshold
       if length(param2) > 3; dt= param2(4); end
-      
+
    end
-   fobliq= [0 0 0 0 1;0 0 0 .5 .5;0 0 0 1 0;0 0 .5 .5 0;0 0 1 0 0; 
+   fobliq= [0 0 0 0 1;0 0 0 .5 .5;0 0 0 1 0;0 0 .5 .5 0;0 0 1 0 0;
                       0 .5 .5 0 0;0 1 0 0 0;.5 .5 0 0 0;1 0 0 0 0];
    fobliq= fobliq( 5-sz:5+sz, 3-ceil(sz/2):3+ceil(sz/2) );
 
    xpeak= imo(yy,xx-1) <= imo(yy,xx) & imo(yy,xx) > imo(yy,xx+1) ;
    ypeak= imo(yy-1,xx) <= imo(yy,xx) & imo(yy,xx) > imo(yy+1,xx) ;
 
-   imht= ( imo >= thresh^2 * 2); # high threshold image   
+   imht= ( imo >= thresh^2 * 2); # high threshold image
    imht(yy,xx)= imht(yy,xx) & ( xpeak | ypeak );
    imht([1,n],:)=0; imht(:,[1,m])=0;
 
-%  imlt= ( imo >= thresh^2 / 2); # low threshold image   
-   imlt= ( imo >= thresh^2 / 1); # low threshold image   
+%  imlt= ( imo >= thresh^2 / 2); # low threshold image
+   imlt= ( imo >= thresh^2 / 1); # low threshold image
    imlt(yy,xx)= imlt(yy,xx) & ( xpeak | ypeak );
    imlt([1,n],:)=0; imlt(:,[1,m])=0;
 
@@ -498,7 +498,7 @@ function [imout, thresh] = edge_andy (im, thresh, param2)
    imee= conv2(imee,dilate,'same') > dt; #
 
 %  ff= find( imht==1 );
-%  imout = bwselect( imee, rem(ff-1, n)+1, ceil(ff/n), 8);  
+%  imout = bwselect( imee, rem(ff-1, n)+1, ceil(ff/n), 8);
    imout = imee;
 endfunction
 
@@ -519,7 +519,7 @@ function bw = simple_thinning(strength)
   bw = x | y;
 endfunction
 
-## Auxiliary function. Finds the zero crossings of the 
+## Auxiliary function. Finds the zero crossings of the
 ## 2-dimensional function f. (By Etienne Grossmann)
 function z = zerocrossings(f)
   z0 = f<0;                 ## Negative
