@@ -1,18 +1,17 @@
-## Copyright (C) 2008 Soren Hauberg
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+## Copyright (C) 2008 Søren Hauberg <soren@hauberg.org>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} @var{accum}= hough_circle (@var{bw}, @var{r})
@@ -26,7 +25,7 @@
 ## accum = hough_circle(bw, [3, 7]);
 ## @end example
 ## If @var{im} is an NxM image @var{accum} will be an NxMx2 array, where
-## @var{accum}(:,:,1) will contain the Hough transform for circles with 
+## @var{accum}(:,:,1) will contain the Hough transform for circles with
 ## radius 3, and @var{accum}(:,:,2) for radius 7. To find good circles you
 ## now need to find local maximas in @var{accum}, which can be a hard problem.
 ## If you find a local maxima in @var{accum}(row, col, 1) it means that a
@@ -41,8 +40,8 @@ function accum = hough_circle(bw, r)
     error("hough_circle: wrong number of input arguments");
   endif
 
-  if (!ismatrix(bw) || ndims(bw) != 2)
-    error("hough_circle: first arguments must be a 2-dimensional matrix");
+  if (! ismatrix (bw))
+    error("hough_circle: BW must be a 2-dimensional matrix");
   endif
 
   if (!isvector(r) || !isreal(r) || any(r<0))
@@ -58,7 +57,7 @@ function accum = hough_circle(bw, r)
   ## Iterate over different radius
   for j = 1:length(r)
     rad = r(j);
-	
+
     ## Compute a filter containing the circle we're looking for.
     circ = circle(rad);
 
