@@ -1,18 +1,17 @@
-## Copyright (C) 2008 Soren Hauberg
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with this program; if not, write to the Free Software
-## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+## Copyright (C) 2008 Søren Hauberg <soren@hauberg.org>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} @var{H} = houghtf (@var{bw})
@@ -70,14 +69,14 @@ function [accum, R] = houghtf(bw, varargin)
   ## Default arguments
   method = "line";
   args = {};
-  
+
   ## Check input arguments
   if (nargin == 0)
     error("houghtf: not enough input arguments");
   endif
 
-  if (!ismatrix(bw) || ndims(bw) != 2)
-    error("houghtf: first arguments must be a 2-dimensional matrix");
+  if (! ismatrix (bw))
+    error("houghtf: BW must be a 2-dimensional matrix");
   endif
 
   if (nargin > 1)
@@ -88,7 +87,7 @@ function [accum, R] = houghtf(bw, varargin)
       args = varargin;
     endif
   endif
-  
+
   ## Choose method
   switch (lower(method))
     case "line"
