@@ -19,7 +19,7 @@
 ## @deftypefn  {Function File} @var{J} = imboxfilt(@var{img})
 ## @deftypefnx {Function File} @var{J} = imboxfilt(@dots{_}, @var{fs})
 ## @deftypefnx {Function File} @var{J} = imboxfilt(@dots{}, @var{name}, @var{value}, @dots{} )
-## Produces box filtering @var{J} of image @var{img}, is quicker than imfilter.
+## Produces box filtering of an image, quicker than imfilter.
 ##
 ## Parameters:
 ## @table @samp
@@ -406,7 +406,7 @@ endfunction
 %! output = imboxfilt (input, 3);
 %! assert (imboxfilt (input, 3), expected, 0.0001); # sadly the test only works with this kind of tolerance
 
-## test 3d-matrix as image
+## test 3D-matrix as image
 %!test
 %! m2d = ones (8, 8);
 %! padded_img = cat (3,m2d * 5, m2d * 17, m2d * 29);
