@@ -15,10 +15,10 @@
 ## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {} {@var{c} =} imfuse (@var{a}, @var{b})
-## @deftypefnx {} {[@var{c}, @var{rc}] =} imfuse (@var{a}, @var{ra}, @var{b}, @var{rb})
-## @deftypefnx {} {@var{c} =} imfuse (@dots{}, @var{method})
-## @deftypefnx {} {@var{c} =} imfuse (@dots{}, @var{name}, @var{value})
+## @deftypefn {Function File} {@var{c} =} imfuse (@var{a}, @var{b})
+## @deftypefnx {Function File} {[@var{c}, @var{rc}] =} imfuse (@var{a}, @var{ra}, @var{b}, @var{rb})
+## @deftypefnx {Function File} {@var{c} =} imfuse (@dots{}, @var{method})
+## @deftypefnx {Function File} {@var{c} =} imfuse (@dots{}, @var{name}, @var{value})
 ## Composite of two images.
 ##
 ## Combines two images using a specified @var{method}.  The smaller image gets
