@@ -18,7 +18,7 @@
 ## @deftypefnx {Function File} {} imhist (@var{I}, @var{n})
 ## @deftypefnx {Function File} {} imhist (@var{X}, @var{cmap})
 ## @deftypefnx {Function File} {[@var{counts}, @var{x}] =} imhist (@dots{})
-## Produce histogram counts of image @var{I}.
+## Produce histogram counts of an image.
 ##
 ## The second argument can either be @var{n}, a scalar that specifies the number
 ## of bins; or @var{cmap}, a colormap in which case @var{X} is expected to be
