@@ -51,6 +51,14 @@
 ## @item "cubic", "bicubic" (default)
 ## Bicubic interpolation method using the 16 neighbor pixels.  At the borders
 ## symmetric padding is used.  This is the default method.
+##
+## @item "lanczos2"
+## Lanczos-2 interpolation method using the 16 neighbor pixels. At the borders
+## symmetric padding is used.
+##
+## @item "lanczos3"
+## Lanczos-2 interpolation method using the 36 neighbor pixels.  At the borders
+## symmetric padding is used.
 ## @end table
 ## By default, the @code{cubic} method is used.
 ##
@@ -263,17 +271,15 @@ function im = imresize (im, varargin)
     if (iscell (method))
       kernel_size = method{2};
       if (scale < 1 && antialiasing)
-        scale_int = 1 / ceil (1 / scale);
-        kernel = @(h) scale_int * method{1} (scale_int * h);
-        kernel_size /= scale_int;
+        kernel = @(h) scale * method{1} (scale * h);
+        kernel_size /= scale;
       else
         kernel = method{1};
       endif
     elseif (strcmp (method, "nearest"))
       if (scale < 1)
-        scale_int = 1 / ceil (1 / scale);
-        kernel = @(h) scale_int * box (scale_int * h);
-        kernel_size = 1 / scale_int;
+        kernel = @(h) scale * box (scale * h);
+        kernel_size = 1 / scale;
       else
         if axis == 1
           im = im(round (idx), :, :);
@@ -285,23 +291,37 @@ function im = imresize (im, varargin)
     elseif (strcmp (method, "linear"))
       kernel_size = 2;
       if (scale < 1 && antialiasing)
-        scale_int = 1 / ceil (1 / scale);
-        kernel = @(h) scale_int * triangle (scale_int * h);
-        kernel_size /= scale_int;
+        kernel = @(h) scale * triangle (scale * h);
+        kernel_size /= scale;
       else
         kernel = @triangle;
       endif
     elseif (strcmp (method, "cubic"))
       kernel_size = 4;
       if (scale < 1 && antialiasing)
-        scale_int = 1 / ceil (1 / scale);
-        kernel = @(h) scale_int * cubic (scale_int * h);
-        kernel_size /= scale_int;
+        kernel = @(h) scale * cubic (scale * h);
+        kernel_size /= scale;
       else
         kernel = @cubic;
       endif
+    elseif (strcmp (method, "lanczos2"))
+      kernel_size = 4;
+      if (scale < 1 && antialiasing)
+        kernel = @(h) scale * lanczos (scale * h, 2);
+        kernel_size /= scale;
+      else
+        kernel = @(h) lanczos (h, 2);
+      endif
+    elseif (strcmp (method, "lanczos3"))
+      kernel_size = 6;
+      if (scale < 1 && antialiasing)
+        kernel = @(h) scale * lanczos (scale * h, 3);
+        kernel_size /= scale;
+      else
+        kernel = @(h) lanczos (h, 3);
+      endif
     else
-      error ("imresize: Interpolation method not supported");
+      error ("imresize: Interpolation method %s is not supported", method);
     endif
 
     ## When rounding the output size up, it can happen that some interpolation
@@ -339,6 +359,12 @@ function w = cubic (h)
     + (-0.5 * absh_cube + 2.5 * absh_sqr - 4 * absh + 2) .* absh12;     ## for 1 < |h| <= 2
 end
 
+## Lanczos interpolation kernel.
+function w = lanczos (d, a)
+  absd = abs (d);
+  absd0a = absd <= a;
+  w = sinc (d) .* sinc (d / a) .* absd0a;  ## for |d| <= a
+endfunction
 
 ## padding by changing indices. Cannot mimic constant value padding, like zero padding
 function idx = pad_indices (i, sz, method = "symmetric")
@@ -369,27 +395,36 @@ function out = conv_interp_vec (img, ZI, kernel, kernel_size, axis, padding = "s
   ## get indexes and distances
   idx = floor (ZI);
   DZ = ZI - idx;
-  pad_size = ceil (kernel_size / 2);
+  pad_size = ceil (kernel_size / 2) + 2;   # add extra two pixels, to be on the safe side
   pad_border = size (img, axis);
 
   ## allocate output
   out_shape = size (img);
   out_shape(axis) = length (ZI);
   out = zeros (out_shape);
+  sum_weights = zeros (out_shape);
 
   ## interpolate
   for shift = 1-pad_size : pad_size
     h = shift - DZ;
     idx_padded = pad_indices (idx + shift, pad_border, padding);
 
+    weights = kernel (h);
+    sum_weights += weights;
+
     if axis == 1
-      out += img(idx_padded, :, :) .* kernel (h);
+      out += img(idx_padded, :, :) .* weights;
     else
-      out += img(:, idx_padded, :) .* kernel (h);
+      out += img(:, idx_padded, :) .* weights;
     endif
   endfor
+
+  sum_weights(sum_weights == 0) = 1;
+  out = out ./ sum_weights;
+
 endfunction
 
+
 ## Test basic features.
 %!test
 %!
@@ -532,7 +567,7 @@ endfunction
 %!
 %! for channels = 1:3
 %!   in = rand (5, 4, channels);
-%!   for method = {"nearest", "bilinear", "bicubic"}
+%!   for method = {"nearest", "bilinear", "bicubic", "lanczos2", "lanczos3"}
 %!     out = imresize (in, 2, method{1});
 %!     for i = 1:size (in, 3)
 %!       assert (out(:, :, i), imresize (in(:, :, i), 2, method{1}))
@@ -720,6 +755,144 @@ endfunction
 %!         81  157  118   64];
 %! assert (imresize (uint8 (in), 1/3, "bicubic", "Antialiasing", true), uint8 (out), 1)
 
+## Test lanczos2 interpolations against some reference results from matlab.
+## The numbers do not match yet.
+## Factor 1.5, gives an output of size 12 x 15 (without requiring to round the size)
+%!test
+%! in = [116  227  153   69  146  194   59  130  139  106
+%!         2   47  137  249   90   75   16   24  158   44
+%!       155   68   46   84  166  156   69  204   32  152
+%!        71  221  137  230  210  153  192  115   30  118
+%!       107  143  108   52   51   73  101   21  175   90
+%!        54  158  143   77   26  168  113  229  165  225
+%!         9   47  133  135  130  207  236   43   19   73
+%!       129   60   59  243   64  181  249   56   32   86];
+%!
+%! out = [116   188   239   174    93    60   133   191   188    76    91   144   140   124   109
+%!         42    92   144   148   164   163   119   123   117    44    38    81   151   118    61
+%!         13    20    48   103   195   229   117    81    68    25    20    57   136   105    47
+%!        147    97    46    47    70   108   146   158   131    56   122   177    62    86   147
+%!        118   139   144    92   116   169   200   188   159   140   167   157    27    69   154
+%!         58   151   220   145   174   220   200   162   144   189   148    82    50    77   116
+%!        101   132   151   119    90    72    74    73    83   115    59    30   142   129    78
+%!         81   121   155   134    87    40    19    67   117    95   108   141   182   180   163
+%!         35    93   152   150   119    74    34   109   183   131   176   215   151   175   219
+%!          2    29    76   131   135   118   115   162   213   228   146    53    36    63    97
+%!         68    54    51    81   153   188   110   141   211   259   149    20    13    42    74
+%!        145   101    53    39   164   240    78   103   198   255   159    40    31    59    91];
+%! assert (imresize (uint32 (in), 1.5, "lanczos2"), uint32 (out), 1)
+%! assert (imresize (uint8 (in), 1.5, "lanczos2"), uint8 (out), 1)
+%!
+## Factor 0.5, gives an output of size 4 x 5 (without requiring to round the size)
+%! out = [ 92  164  124   38  118
+%!        139  116  188  167   69
+%!        121   87   67  107  180
+%!         53  153  141  149   42];
+%! assert (imresize (uint32 (in), 0.5, "lanczos2", "Antialiasing", false), uint32 (out), 1)
+%! assert (imresize (uint8 (in), 0.5, "lanczos2", "Antialiasing", false), uint8 (out), 1)
+%!
+%! out = [106  138  125   81  110
+%!        109  134  153  113   93
+%!        108  109   95  127  146
+%!         67  127  163  150   62];
+%! assert (imresize (uint32 (in), 0.5, "lanczos2", "Antialiasing", true), uint32 (out), 1)
+%! assert (imresize (uint8 (in), 0.5, "lanczos2", "Antialiasing", true), uint8 (out), 1)
+%!
+## Factor 4/3, gives an output of size 10.6667 x 13.3333 rounded up to 11 x 14
+%! out = [116  205  222  139   61  109  181  191   71  105  144  135  113  107
+%!         25   78  128  158  200  139  102  103   34   27   93  158   68   45
+%!         51   34   52  114  196  147  100   86   29   57  100  114   82   74
+%!        161  112   64   51   80  147  180  152   84  175  147   25  142  171
+%!         69  171  190  134  217  228  194  158  187  160   83   24  113  136
+%!         90  152  162  116  119  115  102   97  139   65   59  126   92   83
+%!         90  130  144  110   52   23   50  102   94   86  129  190  146  136
+%!         39  113  158  139   92   38   83  181  125  193  203  153  212  227
+%!          3   32   90  142  125  117  152  213  232  121   35   36   82   94
+%!         87   60   56   99  203  129  115  204  255  121   18   25   70   82
+%!        149   91   43   70  248  125   80  193  255  131   31   37   82   94];
+%! assert (imresize (uint8 (in), 4/3, "lanczos2"), uint8 (out), 1)
+%!
+## Factor 1/3, gives an output of size 2.6667 x 3.3333 rounded up to 3 x 4
+%! out = [ 47   90   24   44
+%!        143   51   21   90
+%!         60   64   56   86];
+%! assert (imresize (uint8 (in), 1/3, "lanczos2", "Antialiasing", false), uint8 (out), 1)
+%!
+%! out = [115  135   97  100
+%!        112  119  124  125
+%!         81  158  119   63];
+%! assert (imresize (uint8 (in), 1/3, "lanczos2", "Antialiasing", true), uint8 (out), 1)
+
+## Test lanczos3 interpolations against some reference results from matlab
+## without anti-aliasing with
+## uint8 (imresize (in, <FACTOR>, "lanczos3", "Antialiasing", "Antialiasing", false))
+## The floating point error is less than ?????, but with integer Matlab rounds
+## wrong. So a difference of 1 is acceptable.
+## Factor 1.5, gives an output of size 12 x 15 (without requiring to round the size)
+%!test
+%! in = [116  227  153   69  146  194   59  130  139  106
+%!         2   47  137  249   90   75   16   24  158   44
+%!       155   68   46   84  166  156   69  204   32  152
+%!        71  221  137  230  210  153  192  115   30  118
+%!       107  143  108   52   51   73  101   21  175   90
+%!        54  158  143   77   26  168  113  229  165  225
+%!         9   47  133  135  130  207  236   43   19   73
+%!       129   60   59  243   64  181  249   56   32   86];
+%!
+%! out = [ 118    202    250    181     73     48    129    216    191     80     91    157    140    121    114
+%!          26     86    143    154    180    176    117    117    113     47     18     74    158    126     46
+%!          17     16     37     96    203    225    115     73     69     22      8     62    139    112     40
+%!         149     89     35     42     69    106    141    161    120     45    121    174     68     76    152
+%!         122    155    151     93    104    171    212    206    167    141    196    171     15     50    179
+%!          46    159    221    150    171    229    206    151    144    188    148     67     48     75    110
+%!          94    134    155    123     91     79     78     70     86    126     50     20    137    136     64
+%!          87    126    154    131     79     23     -1     60    110     84     96    153    199    194    166
+%!          25     93    157    156    123     71     35    119    186    135    180    219    149    165    227
+%!          -2     24     77    136    141    113    113    160    222    233    152     55     30     64    105
+%!          66     47     41     78    162    185    120    130    223    270    147     -1     -3     37     65
+%!         154    110     48     27    178    240     79     75    208    258    164     41     29     65     99];
+%! assert (imresize (int32 (in), 1.5, "lanczos3"), int32 (out), 1)
+%! assert (imresize (uint8 (in), 1.5, "lanczos3"), uint8 (out), 1)
+%!
+## Factor 0.5, gives an output of size 4 x 5 (without requiring to round the size)
+%! out = [ 86  180  117   18  126
+%!        155  104  206  196   51
+%!        126   79   59   96  194
+%!         47  162  130  147   37];
+%! assert (imresize (uint8 (in), 0.5, "lanczos3", "Antialiasing", false), uint8 (out), 1)
+%!
+%! out = [106  142  123   85  111
+%!        104  138  155  104   91
+%!        109  112   91  131  147
+%!         68  119  172  149   59];
+%! assert (imresize (uint8 (in), 0.5, "lanczos3", "Antialiasing", true), uint8 (out), 1)
+%!
+## Factor 4/3, gives an output of size 10.6667 x 13.3333 rounded up to 11 x 14
+%! out = [117  214  237  132   50   98  201  193   73  103  156  130  116  110
+%!         12   76  129  165  216  142   95  101   37    7   95  164   68   21
+%!         55   23   30  112  195  144   92   81   20   47  108  116   83   67
+%!        164  118   65   49   77  152  194  152   82  189  150   17  137  196
+%!         66  182  191  129  211  237  192  163  185  177   80   20  113  158
+%!         80  155  169  119  127  126   98   97  150   50   38  128   83   59
+%!         96  131  146  104   41    2   42   97   84   79  145  203  158  133
+%!         32  112  167  140   96   31   91  182  128  196  206  147  209  239
+%!          1   29   94  143  129  112  150  219  235  127   29   37   83  104
+%!         84   55   42  103  206  138  106  213  255  117    0   22   59   77
+%!        164  107   26   71  255  129   49  198  254  139   30   48   89  108];
+%! assert (imresize (uint8 (in), 4/3, "lanczos3"), uint8 (out), 1)
+%!
+## Factor 1/3, gives an output of size 2.6667 x 3.3333 rounded up to 3 x 4
+%! out = [ 47   90   24   44
+%!        143   51   21   90
+%!         60   64   56   86];
+%! assert (imresize (uint8 (in), 1/3, "lanczos3", "Antialiasing", false), uint8 (out), 1)
+%!
+%! out = [116  137   95  100
+%!        110  120  125  126
+%!         74  163  122   55];
+%! assert (imresize (uint8 (in), 1/3, "lanczos3", "Antialiasing", true), uint8 (out), 1)
+
+%!test
 ## Reduce the size of a checkerboard, such that it turns into gray
 %!test
 %!
