@@ -1,17 +1,17 @@
-## Copyright (C) 2007  Soren Hauberg
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3, or (at your option)
-## any later version.
-## 
-## This program is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details. 
-## 
-## You should have received a copy of the GNU General Public License
-## along with this file.  If not, see <http://www.gnu.org/licenses/>.
+## Copyright (C) 2007 Søren Hauberg <soren@hauberg.org>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} @var{J} = imsmooth(@var{I}, @var{name}, @var{options})
@@ -45,7 +45,7 @@
 ## numbers, but the result has the same type as the input. Also, the size of the
 ## smoothed image is the same as the input image.
 ##
-## @strong{Isotropic Gaussian smoothing}
+## @strong{Gaussian - Isotropic Gaussian smoothing}
 ##
 ## The image is convolved with a Gaussian filter with spread @var{sigma}.
 ## By default @var{sigma} is @math{0.5}, but this can be changed. If the third
@@ -53,7 +53,7 @@
 ##
 ## The image is extrapolated symmetrically before the convolution operation.
 ##
-## @strong{Rectangular averaging linear filter}
+## @strong{Average - Rectangular averaging linear filter}
 ##
 ## The image is convolved with @var{N} by @var{M} rectangular averaging filter.
 ## By default a 3 by 3 filter is used, but this can e changed. If the third
@@ -63,7 +63,7 @@
 ##
 ## The image is extrapolated symmetrically before the convolution operation.
 ##
-## @strong{Circular averaging linear filter}
+## @strong{Disk - Circular averaging linear filter}
 ##
 ## The image is convolved with circular averaging filter. By default the filter
 ## has a radius of 5, but this can e changed. If the third input argument is a
@@ -71,22 +71,22 @@
 ##
 ## The image is extrapolated symmetrically before the convolution operation.
 ##
-## @strong{Median filtering}
+## @strong{Median - Median filtering}
 ##
 ## Each pixel is replaced with the median of the pixels in the local area. By
 ## default, this area is 3 by 3, but this can be changed. If the third input
 ## argument is a scalar @var{N} the area will be @var{N} by @var{N}, and if it's
 ## a two-vector [@var{N}, @var{M}] the area will be @var{N} by @var{M}.
-## 
+##
 ## The image is extrapolated symmetrically before the filtering is performed.
 ##
-## @strong{Gaussian bilateral filtering}
+## @strong{Bilateral - Gaussian bilateral filtering}
 ##
 ## The image is smoothed using Gaussian bilateral filtering as described by
 ## Tomasi and Manduchi [2]. The filtering result is computed as
 ## @example
 ## @var{J}(x0, y0) = k * SUM SUM @var{I}(x,y) * w(x, y, x0, y0, @var{I}(x0,y0), @var{I}(x,y))
-##                  x   y        
+##                  x   y
 ## @end example
 ## where @code{k} a normalisation variable, and
 ## @example
@@ -94,7 +94,7 @@
 ##   = exp(-0.5*d([x0,y0],[x,y])^2/@var{sigma_d}^2)
 ##     * exp(-0.5*d(@var{I}(x0,y0),@var{I}(x,y))^2/@var{sigma_r}^2),
 ## @end example
-## with @code{d} being the Euclidian distance function. The two paramteres
+## with @code{d} being the Euclidian distance function. The two parameters
 ## @var{sigma_d} and @var{sigma_r} control the amount of smoothing. @var{sigma_d}
 ## is the size of the spatial smoothing filter, while @var{sigma_r} is the size
 ## of the range filter. When @var{sigma_r} is large the filter behaves almost
@@ -102,7 +102,7 @@
 ## small edges are preserved better. By default @var{sigma_d} is 2, and @var{sigma_r}
 ## is @math{10/255} for floating points images (with integer images this is
 ## multiplied with the maximal possible value representable by the integer class).
-## 
+##
 ## The image is extrapolated symmetrically before the filtering is performed.
 ##
 ## @strong{Perona and Malik}
@@ -148,7 +148,7 @@
 ## @var{J} = imsmooth(@var{I}, "p&m", 25, 0.25, @var{g});
 ## @end example
 ##
-## @strong{Custom Gaussian Smoothing}
+## @strong{Custom Gaussian - Custom Gaussian Smoothing}
 ##
 ## The image is smoothed using a Gaussian filter with a spatially varying covariance
 ## matrix. The third and fourth input arguments contain the Eigenvalues of the
@@ -192,8 +192,8 @@ function J = imsmooth(I, name = "Gaussian", varargin)
   if (nargin == 0)
     print_usage();
   endif
-  if (!ismatrix(I))
-    error("imsmooth: first input argument must be an image");
+  if (! isimage (I))
+    error("imsmooth: I must be an image");
   endif
   [imrows, imcols, imchannels, tmp] = size(I);
   if ((imchannels != 1 && imchannels != 3) || tmp != 1)
@@ -207,10 +207,10 @@ function J = imsmooth(I, name = "Gaussian", varargin)
     error("imsmooth: second input must be a string");
   endif
   len = length(varargin);
-  
+
   ## Save information for later
   C = class(I);
-  
+
   ## Take action depending on 'name'
   switch (lower(name))
     ##############################
@@ -230,7 +230,7 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       h = ceil(3*s);
       f = exp( (-(-h:h).^2)./(2*s^2) ); f /= sum(f);
       ## Pad image
-      I = double(impad(I, h, h, "symmetric"));
+      I = double (padarray (I, [h h], "symmetric"));
       ## Perform the filtering
       for i = imchannels:-1:1
         J(:,:,i) = conv2(f, f, I(:,:,i), "valid");
@@ -255,12 +255,14 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       f2 = ones(1,s(1))/s(1);
       f1 = ones(1,s(2))/s(2);
       ## Pad image
-      I = impad(double(I), floor([s(2), s(2)-1]/2), floor([s(1), s(1)-1]/2), "symmetric");
+      I = padarray (I, floor ( [s(1) s(2)]   /2), "symmetric", "pre");
+      I = padarray (I, floor (([s(1) s(2)]-1)/2), "symmetric", "post");
+      I = double (I);
       ## Perform the filtering
       for i = imchannels:-1:1
-        J(:,:,i) = conv2(f1, f2, I(:,:,i), "valid");
+        J(:,:,i) = conv2 (f1, f2, I(:,:,i), "valid");
       endfor
-      
+
     ##############################
     ###   Circular averaging   ###
     ##############################
@@ -277,12 +279,12 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       ## Compute filter
       f = fspecial("disk", r);
       ## Pad image
-      I = impad(double(I), r, r, "symmetric");
+      i = double (padarray (I, [r r], "symmetric"));
       ## Perform the filtering
       for i = imchannels:-1:1
         J(:,:,i) = conv2(I(:,:,i), f, "valid");
       endfor
-    
+
     ############################
     ###   Median Filtering   ###
     ############################
@@ -304,7 +306,7 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       for i = imchannels:-1:1
         J(:,:,i) = medfilt2(I(:,:,i), s, "symmetric");
       endfor
-    
+
     ###############################
     ###   Bilateral Filtering   ###
     ###############################
@@ -331,10 +333,10 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       endif
       ## Pad image
       s = max([round(3*sigma_d),1]);
-      I = impad(I, s, s, "symmetric");
+      I = padarray (I, [s s], "symmetric");
       ## Perform the filtering
-      J = __bilateral__(I, sigma_d, sigma_r);
-    
+      J = __bilateral__(I, sigma_d, sigma_r, s);
+
     ############################
     ###   Perona and Malik   ###
     ############################
@@ -384,7 +386,7 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       for i = imchannels:-1:1
         J(:,:,i) = pm(I(:,:,i), iter, lambda, method);
       endfor
-    
+
     #####################################
     ###   Custom Gaussian Smoothing   ###
     #####################################
@@ -399,7 +401,7 @@ function J = imsmooth(I, name = "Gaussian", varargin)
       for k = 1:3
         if (isscalar (varargin {k}))
           varargin {k} = repmat (varargin {k}, imrows, imcols);
-        elseif (ismatrix (varargin {k}) && ndims (varargin {k}) == 2)
+        elseif (isnumeric (varargin {k}) && ismatrix (varargin {k}))
           if (rows (varargin {k}) != imrows || columns (varargin {k}) != imcols)
             error (["imsmooth: %s input argument must have same number of rows "
                     "and columns as the input image"], arg_names {k});
@@ -411,15 +413,15 @@ function J = imsmooth(I, name = "Gaussian", varargin)
           error ("imsmooth: %s input argument must be of class 'double'", arg_names {k});
         endif
       endfor
-      
+
       ## Perform the smoothing
       for i = imchannels:-1:1
         J(:,:,i) = __custom_gaussian_smoothing__ (I(:,:,i), varargin {:});
       endfor
-    
+
     ######################################
     ###   Mean Shift Based Smoothing   ###
-    ######################################  
+    ######################################
     # NOT YET IMPLEMENTED
     #case "mean shift"
     #  J = mean_shift(I, varargin{:});
@@ -430,7 +432,7 @@ function J = imsmooth(I, name = "Gaussian", varargin)
     otherwise
       error("imsmooth: unsupported smoothing type '%s'", name);
   endswitch
-  
+
   ## Cast the result to the same class as the input
   J = cast(J, C);
 endfunction
@@ -440,10 +442,10 @@ function J = pm(I, iter, lambda, g)
   ## Initialisation
   [imrows, imcols] = size(I);
   J = I;
-  
+
   for i = 1:iter
     ## Pad image
-    padded = impad(J, 1, 1, "replicate");
+    padded = padarray (J, [1 1], "circular");
 
     ## Spatial derivatives
     dN = padded(1:imrows, 2:imcols+1) - J;
@@ -475,7 +477,7 @@ function J = mean_shift(I, s1, s2)
   m01 = conv2(I.*y, f, "same")./tmp;
   ms_x = round( m10./m00 ); # konverter ms_x og ms_y til linære indices og arbejd med dem!
   ms_y = round( m01./m00 );
-  
+
   ms = sub2ind(sz, ms_y, ms_x);
   %for i = 1:10
   i = 0;
@@ -493,8 +495,32 @@ function J = mean_shift(I, s1, s2)
     %endfor
   endwhile
   %endfor
-  
+
   ## Compute result
   J = I(ms);
 endfunction
 #}
+
+%!test
+%! ## checking Bilateral Filter
+%!
+%! ##  constant image remain the same after Bilateral Filter
+%! A = uint8(255*ones(128,128));
+%! B = uint8(imsmooth(A, 'Bilateral', 2, 10));
+%! assert (A,B);
+%!
+%! ## Bilateral Filter does not smear outlayers
+%! A = zeros(256,256);
+%! A(128,128) = 256;
+%! ## bilateral filter does not smear outlayers
+%! B = imsmooth(A, 'Bilateral', 2, 10);
+%! assert (A,B,1.e-140);
+%!
+%! ## When sigma_r is large the filter behaves almost
+%! ## like the isotropic Gaussian filter
+%!
+%! A0 = fspecial ('gaussian',100,100);
+%! A = uint8(A0/max(max(A0))*255);
+%! B1 = imsmooth(A, 'Bilateral', 2, 100);
+%! B2 = imsmooth(A, 'Gaussian', 2);
+%! assert (B1,B2);
