@@ -16,7 +16,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} isind (@var{img})
-## Return true if @var{img} is an indexed image.
+## Return true if a given image is an indexed image.
 ##
 ## A variable can be considered an indexed image if it is a non-sparse,
 ## real array of size @nospell{MxNx1xK}, and:
