@@ -338,7 +338,7 @@ DEFUN_DLD(bwlabeln, args, , "\
 -*- texinfo -*-\n\
 @deftypefn  {Loadable Function} {[@var{l}, @var{num}] =} bwlabeln (@var{bw})\n\
 @deftypefnx {Loadable Function} {[@var{l}, @var{num}] =} bwlabeln (@var{bw}, @var{n})\n\
-Label foreground objects in the n-dimensional binary image @var{bw}.\n\
+Label foreground objects in the n-dimensional binary image.\n\
 \n\
 The optional argument @var{n} sets the connectivity and defaults 26,\n\
 for 26-connectivity in 3-D images. Other possible values are 18 and 6\n\
