@@ -22,7 +22,6 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <octave/oct.h>
-#include "config.h"
 
 DEFUN_DLD(hough_line, args, , "\
 -*- texinfo -*-\n\
@@ -48,13 +47,8 @@ For a Matlab compatible Hough transform see hough.m\n\
     print_usage ();
 
   const Matrix I = args (0).matrix_value ();
-#if defined HAVE_RANGE_IN_OCTAVE_NAMESPACE
   const ColumnVector thetas = (DEF_THETA) ? ColumnVector (octave::range<double> (-M_PI/2.0, M_PI/180.0, M_PI/2.0).array_value ())
                                           : ColumnVector (args (1).vector_value ());
-#else
-  const ColumnVector thetas = (DEF_THETA) ? ColumnVector (Range (-M_PI/2.0, M_PI/2.0, M_PI/180.0).matrix_value ())
-                                          : ColumnVector (args (1).vector_value ());
-#endif
 
   const int r = I.rows ();
   const int c = I.columns ();
@@ -62,11 +56,7 @@ For a Matlab compatible Hough transform see hough.m\n\
 
   const double diag_length = sqrt ((r-1)*(r-1) + (c-1)*(c-1));
   const int nr_bins = 2 * (int)ceil (diag_length) + 1;
-#if defined HAVE_RANGE_IN_OCTAVE_NAMESPACE
   RowVector bins = RowVector (octave::range<double> (1, nr_bins).array_value ()) - ceil (nr_bins/2.0);
-#else
-  RowVector bins = RowVector (Range(1, nr_bins).matrix_value ()) - ceil (nr_bins/2.0);
-#endif
   const int bins_length = bins.numel ();
 
   Matrix J (bins_length, thetas_length, 0.0);
