@@ -47,8 +47,8 @@ template<class T>
 static T
 intlut (const T& A, const T& lut)
 {
-  const auto* A_vec = A.fortran_vec ();
-  const auto* lut_vec = lut.fortran_vec ();
+  const auto* A_vec = A.data ();
+  const auto* lut_vec = lut.data ();
 
   T B (A.dims ());
   auto* B_vec = B.fortran_vec ();
