@@ -85,7 +85,7 @@ public:
   get_ids (const NDArray& L) const
   {
     std::vector<octave_idx_type> ids;
-    const double* v = L.fortran_vec ();
+    const double* v = L.data ();
 
     for (size_t i = 0; i < voxels.size (); i++)
       if (v[i])
