@@ -21,10 +21,6 @@
 #include <octave/Cell.h>
 #include <octave/oct-map.h>
 
-#define WANTS_FEVAL 1
-#define WANTS_OCTAVE_IMAGE_VALUE 1
-#include "octave-wrappers.h"
-
 #include "connectivity.h"
 using namespace octave_image_pkg;
 
@@ -35,8 +31,7 @@ imregionalmin (const T& im, const connectivity& conn)
   octave_value_list args (2);
   args(0) = im;
   args(1) = conn.mask;
-  const octave_value regional_min = octave_image::feval ("imregionalmin",
-                                                         args)(0);
+  const octave_value regional_min = octave::feval ("imregionalmin", args)(0);
   return regional_min.bool_array_value ();
 }
 
@@ -46,7 +41,7 @@ bwlabeln (const boolNDArray& bw, const connectivity& conn)
   octave_value_list args (2);
   args(0) = bw;
   args(1) = conn.mask;
-  const octave_value label = octave_image::feval ("bwlabeln", args)(0);
+  const octave_value label = octave::feval ("bwlabeln", args)(0);
   return label.array_value ();
 }
 
@@ -310,7 +305,7 @@ or with a binary matrix representing a connectivity array.  Defaults to\n\
         }
     }
 
-  const octave_image::value im (args(0));
+  const octave_value im (args(0));
 #define IF_TYPE(IS_TYPE, VALUE_TYPE) \
   if (im.is ## IS_TYPE ()) \
     return octave_value (watershed (im. VALUE_TYPE ## array_value (), \
